@@ -12,8 +12,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from unittest import mock
+
 import jinja2
-import mock
 import yaml
 
 from heatclient import exc as heat_exc
@@ -37,6 +38,11 @@ JINJA_SNIPPET = r"""
       DefaultPasswords: {get_attr: [DefaultPasswords, passwords]}
 {% endfor %}"""
 
+JINJA_RAISE_CONFIG = r"""
+# Jinja raise extension
+{{ raise('MESSAGE') }}
+"""
+
 ROLE_DATA_YAML = r"""
 -
   name: CustomRole
@@ -374,22 +380,36 @@ class ProcessTemplatesTest(base.TestCase):
         self.assertTrue({'name': ['puppet/controller-role.yaml']} ==
                         template_utils.get_j2_excludes_file(swift))
 
-        def return_multiple_files(*args):
+        def return_multiple_files2(*args):
             if args[1] == constants.OVERCLOUD_J2_EXCLUDES:
                 return ['', J2_EXCLUDES_EMPTY_LIST]
-        swift.get_object = mock.MagicMock(side_effect=return_multiple_files)
+        swift.get_object = mock.MagicMock(side_effect=return_multiple_files2)
         # Test - J2 exclude file with no template to exlude
         self.assertTrue(
             {'name': []} == template_utils.get_j2_excludes_file(swift))
 
-        def return_multiple_files(*args):
+        def return_multiple_files3(*args):
             if args[1] == constants.OVERCLOUD_J2_EXCLUDES:
                 return ['', J2_EXCLUDES_EMPTY_FILE]
-        swift.get_object = mock.MagicMock(side_effect=return_multiple_files)
+        swift.get_object = mock.MagicMock(side_effect=return_multiple_files3)
         # Test - J2 exclude file empty
         self.assertTrue(
             {'name': []} == template_utils.get_j2_excludes_file(swift))
 
+    def test_j2_render_and_put_raise_in_template(self):
+
+        # setup swift
+        swift = mock.MagicMock()
+        swift.get_object = mock.MagicMock()
+        swift.get_container = mock.MagicMock()
+
+        # Test
+        args = (swift, JINJA_RAISE_CONFIG, {'role': 'CustomRole'},
+                'customrole-config.yaml', constants.DEFAULT_CONTAINER_NAME)
+        self.assertRaises(RuntimeError,
+                          template_utils.j2_render_and_put,
+                          *args)
+
     def test_heat_resource_exists(self):
         heat_client = mock.MagicMock()
         stack = mock.MagicMock(stack_name='overcloud')
